@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -325,15 +325,12 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
             )
 
     def list_voices(
         self,
-        request: cloud_tts.ListVoicesRequest = None,
+        request: Union[cloud_tts.ListVoicesRequest, dict] = None,
         *,
         language_code: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -343,7 +340,7 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
         r"""Returns a list of Voice supported for synthesis.
 
         Args:
-            request (google.cloud.texttospeech_v1.types.ListVoicesRequest):
+            request (Union[google.cloud.texttospeech_v1.types.ListVoicesRequest, dict]):
                 The request object. The top-level message sent by the
                 client for the `ListVoices` method.
             language_code (str):
@@ -406,7 +403,7 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
 
     def synthesize_speech(
         self,
-        request: cloud_tts.SynthesizeSpeechRequest = None,
+        request: Union[cloud_tts.SynthesizeSpeechRequest, dict] = None,
         *,
         input: cloud_tts.SynthesisInput = None,
         voice: cloud_tts.VoiceSelectionParams = None,
@@ -419,7 +416,7 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
         after all text input has been processed.
 
         Args:
-            request (google.cloud.texttospeech_v1.types.SynthesizeSpeechRequest):
+            request (Union[google.cloud.texttospeech_v1.types.SynthesizeSpeechRequest, dict]):
                 The request object. The top-level message sent by the
                 client for the `SynthesizeSpeech` method.
             input (google.cloud.texttospeech_v1.types.SynthesisInput):
@@ -490,6 +487,19 @@ class TextToSpeechClient(metaclass=TextToSpeechClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
